@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2020 The PHP Group                                |
+  | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -49,6 +49,9 @@ using namespace drv;
 
 static zend_class_entry *mysqlx_row_result_class_entry;
 
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_row_result__construct, 0, ZEND_RETURN_VALUE, 0)
+ZEND_END_ARG_INFO()
+
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_row_result__fetch_one, 0, ZEND_RETURN_VALUE, 0)
 ZEND_END_ARG_INFO()
 
@@ -280,7 +283,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_row_result, getColumnNames)
 }
 
 static const zend_function_entry mysqlx_row_result_methods[] = {
-	PHP_ME(mysqlx_row_result, __construct,			nullptr,																ZEND_ACC_PRIVATE)
+	PHP_ME(mysqlx_row_result, __construct, arginfo_mysqlx_row_result__construct, ZEND_ACC_PRIVATE)
 	PHP_ME(mysqlx_row_result, fetchOne,				arginfo_mysqlx_row_result__fetch_one,				ZEND_ACC_PUBLIC)
 	PHP_ME(mysqlx_row_result, fetchAll,				arginfo_mysqlx_row_result__fetch_all,				ZEND_ACC_PUBLIC)
 
