@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2020 The PHP Group                                |
+  | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -28,6 +28,30 @@ std::ostream& operator<<(std::ostream& os, const string& str)
 	return os << str.c_str();
 }
 
+
+void single_separator_split(
+        util::vector< util::string >& output,
+        const util::string& input,
+        const char separator
+)
+{
+    if( input.empty() ) {
+        return;
+    }
+    size_t idx{ 0 }, last{ 0 };
+    for( ; idx < input.size() ; ++idx ){
+        if( input[ idx ] == separator ) {
+            util::string token = input.substr( last, idx - last );
+            output.push_back( token );
+            last = idx + 1;
+        }
+    }
+    if( idx >= last ) {
+        util::string token = input.substr( last );
+        output.push_back( token );
+    }
+}
+
 } // namespace util
 
 } // namespace mysqlx
